# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api.proto',
  package='api',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\tapi.proto\x12\x03\x61pi\"\xfb\x1b\n\x07\x43ommand\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x05\x12\x0f\n\x07session\x18\x02 \x01(\x05\x12$\n\x08openChan\x18\x03 \x01(\x0b\x32\x10.api.OpenChannelH\x00\x12*\n\x0bopenChanRes\x18\x04 \x01(\x0b\x32\x13.api.OpenChannelResH\x00\x12&\n\tcloseChan\x18\x05 \x01(\x0b\x32\x11.api.CloseChannelH\x00\x12,\n\x0c\x63loseChanRes\x18\x06 \x01(\x0b\x32\x14.api.CloseChannelResH\x00\x12-\n\x0e\x63ontainerState\x18\t \x01(\x0b\x32\x13.api.ContainerStateH\x00\x12!\n\x08portOpen\x18\n \x01(\x0b\x32\r.api.PortOpenH\x00\x12\x1b\n\x05toast\x18\x0b \x01(\x0b\x32\n.api.ToastH\x00\x12\x1f\n\x07runMain\x18\x10 \x01(\x0b\x32\x0c.api.RunMainH\x00\x12\x1b\n\x05\x63lear\x18\x11 \x01(\x0b\x32\n.api.ClearH\x00\x12\x0e\n\x04\x65val\x18\x14 \x01(\tH\x00\x12\x10\n\x06result\x18\x15 \x01(\tH\x00\x12\x0f\n\x05input\x18\x16 \x01(\tH\x00\x12\x10\n\x06output\x18\x17 \x01(\tH\x00\x12\x0f\n\x05\x65rror\x18\x18 \x01(\tH\x00\x12!\n\x08saneTerm\x18\x1a \x01(\x0b\x32\r.api.SaneTermH\x00\x12%\n\nresizeTerm\x18\x1b \x01(\x0b\x32\x0f.api.ResizeTermH\x00\x12\x1b\n\x05state\x18\x1c \x01(\x0e\x32\n.api.StateH\x00\x12\x15\n\x02ok\x18\x1e \x01(\x0b\x32\x07.api.OKH\x00\x12\x1c\n\x07persist\x18\x1f \x01(\x0b\x32\t.api.FileH\x00\x12\"\n\rpersistMirror\x18) \x01(\x0b\x32\t.api.FileH\x00\x12\x1a\n\x05write\x18  \x01(\x0b\x32\t.api.FileH\x00\x12\x1b\n\x06remove\x18! \x01(\x0b\x32\t.api.FileH\x00\x12\x19\n\x04move\x18\" \x01(\x0b\x32\t.api.MoveH\x00\x12\x1e\n\ttryRemove\x18$ \x01(\x0b\x32\t.api.FileH\x00\x12\x1a\n\x05mkdir\x18\' \x01(\x0b\x32\t.api.FileH\x00\x12\x19\n\x04read\x18# \x01(\x0b\x32\t.api.FileH\x00\x12\x1c\n\x07readdir\x18% \x01(\x0b\x32\t.api.FileH\x00\x12\x1b\n\x05\x66iles\x18& \x01(\x0b\x32\n.api.FilesH\x00\x12\x19\n\x04\x66ile\x18( \x01(\x0b\x32\t.api.FileH\x00\x12)\n\x0c\x63heckChanges\x18* \x01(\x0b\x32\x11.api.CheckChangesH\x00\x12\"\n\x0c\x63hangedFiles\x18+ \x01(\x0b\x32\n.api.FilesH\x00\x12\'\n\x0blintResults\x18, \x01(\x0b\x32\x10.api.LintResultsH\x00\x12.\n\x10runContainedTest\x18\x46 \x01(\x0b\x32\x12.api.ContainedTestH\x00\x12%\n\ntestResult\x18G \x01(\x0b\x32\x0f.api.TestResultH\x00\x12\x17\n\rdebuggerStart\x18Z \x01(\tH\x00\x12$\n\x0c\x64\x65\x62uggerStep\x18[ \x01(\x0b\x32\x0c.api.RunMainH\x00\x12*\n\x0e\x64\x65\x62uggerStatus\x18\\ \x01(\x0b\x32\x10.api.DebugStatusH\x00\x12-\n\x0e\x65nsurePackages\x18\x64 \x01(\x0b\x32\x13.api.EnsurePackagesH\x00\x12\x19\n\x04ping\x18x \x01(\x0b\x32\t.api.PingH\x00\x12\x19\n\x04pong\x18y \x01(\x0b\x32\t.api.PongH\x00\x12\x1b\n\x05hello\x18z \x01(\x0b\x32\n.api.HelloH\x00\x12\x1f\n\x07goodbye\x18{ \x01(\x0b\x32\x0c.api.GoodbyeH\x00\x12\x1a\n\x04hint\x18\x82\x01 \x01(\x0b\x32\t.api.HintH\x00\x12 \n\x07\x63onnect\x18\x96\x01 \x01(\x0b\x32\x0c.api.ConnectH\x00\x12\x1a\n\x04send\x18\x97\x01 \x01(\x0b\x32\t.api.SendH\x00\x12\x1a\n\x04recv\x18\x98\x01 \x01(\x0b\x32\t.api.RecvH\x00\x12&\n\ndisconnect\x18\x99\x01 \x01(\x0b\x32\x0f.api.DisconnectH\x00\x12(\n\x0b\x66ileAuthReq\x18\xc8\x01 \x01(\x0b\x32\x10.api.FileAuthReqH\x00\x12(\n\x0b\x66ileAuthRes\x18\xc9\x01 \x01(\x0b\x32\x10.api.FileAuthResH\x00\x12\x32\n\x10mutliFileAuthRes\x18\xca\x01 \x01(\x0b\x32\x15.api.MultiFileAuthResH\x00\x12(\n\x0blistObjects\x18\xcd\x01 \x01(\x0b\x32\x10.api.ListObjectsH\x00\x12\x30\n\x0flistObjectsResp\x18\xce\x01 \x01(\x0b\x32\x14.api.ListObjectsRespH\x00\x12\x1c\n\x02ot\x18\xdc\x01 \x01(\x0b\x32\r.api.OTPacketH\x00\x12\"\n\x08otstatus\x18\xdd\x01 \x01(\x0b\x32\r.api.OTStatusH\x00\x12&\n\notLinkFile\x18\xde\x01 \x01(\x0b\x32\x0f.api.OTLinkFileH\x00\x12%\n\x0botNewCursor\x18\xdf\x01 \x01(\x0b\x32\r.api.OTCursorH\x00\x12(\n\x0eotDeleteCursor\x18\xe0\x01 \x01(\x0b\x32\r.api.OTCursorH\x00\x12.\n\x0eotFetchRequest\x18\xe1\x01 \x01(\x0b\x32\x13.api.OTFetchRequestH\x00\x12\x30\n\x0fotFetchResponse\x18\xe2\x01 \x01(\x0b\x32\x14.api.OTFetchResponseH\x00\x12\x1c\n\x05\x66lush\x18\xfb\x01 \x01(\x0b\x32\n.api.FlushH\x00\x12\x1c\n\x05\x64\x65\x62ug\x18\xe6\x01 \x01(\x0b\x32\n.api.DebugH\x00\x12\"\n\x08startVCR\x18\xe7\x01 \x01(\x0b\x32\r.api.StartVCRH\x00\x12 \n\x07readVCR\x18\xe8\x01 \x01(\x0b\x32\x0c.api.ReadVCRH\x00\x12\x1e\n\x06VCRLog\x18\xe9\x01 \x01(\x0b\x32\x0b.api.VCRLogH\x00\x12\x1a\n\x04\x61uth\x18\xeb\x01 \x01(\x0b\x32\t.api.AuthH\x00\x12\"\n\x08\x65xecInfo\x18\xf0\x01 \x01(\x0b\x32\r.api.ExecInfoH\x00\x12,\n\rsubscribeFile\x18\x80\x02 \x01(\x0b\x32\x12.api.SubscribeFileH\x00\x12$\n\tfileEvent\x18\x81\x02 \x01(\x0b\x32\x0e.api.FileEventH\x00\x12\x1e\n\x06roster\x18\x84\x02 \x01(\x0b\x32\x0b.api.RosterH\x00\x12\x1a\n\x04join\x18\x85\x02 \x01(\x0b\x32\t.api.UserH\x00\x12\x1a\n\x04part\x18\x86\x02 \x01(\x0b\x32\t.api.UserH\x00\x12\x1a\n\x04\x65xec\x18\x8e\x02 \x01(\x0b\x32\t.api.ExecH\x00\x12,\n\rpackageSearch\x18\x98\x02 \x01(\x0b\x32\x12.api.PackageSearchH\x00\x12\x34\n\x11packageSearchResp\x18\x99\x02 \x01(\x0b\x32\x16.api.PackageSearchRespH\x00\x12(\n\x0bpackageInfo\x18\x9a\x02 \x01(\x0b\x32\x10.api.PackageInfoH\x00\x12\x30\n\x0fpackageInfoResp\x18\x9b\x02 \x01(\x0b\x32\x14.api.PackageInfoRespH\x00\x12&\n\npackageAdd\x18\x9c\x02 \x01(\x0b\x32\x0f.api.PackageAddH\x00\x12,\n\rpackageRemove\x18\x9d\x02 \x01(\x0b\x32\x12.api.PackageRemoveH\x00\x12.\n\x0epackageInstall\x18\x9e\x02 \x01(\x0b\x32\x13.api.PackageInstallH\x00\x12\x38\n\x13packageListSpecfile\x18\x9f\x02 \x01(\x0b\x32\x18.api.PackageListSpecfileH\x00\x12@\n\x17packageListSpecfileResp\x18\xa0\x02 \x01(\x0b\x32\x1c.api.PackageListSpecfileRespH\x00\x12\x32\n\x10packageCacheSave\x18\xa1\x02 \x01(\x0b\x32\x15.api.PackageCacheSaveH\x00\x12(\n\x0b\x63hatMessage\x18\xb6\x02 \x01(\x0b\x32\x10.api.ChatMessageH\x00\x12&\n\nchatTyping\x18\xb7\x02 \x01(\x0b\x32\x0f.api.ChatTypingH\x00\x12.\n\x0e\x63hatScrollback\x18\xb8\x02 \x01(\x0b\x32\x13.api.ChatScrollbackH\x00\x12&\n\nfsSnapshot\x18\xca\x02 \x01(\x0b\x32\x0f.api.FSSnapshotH\x00\x12\"\n\nfsTakeLock\x18\xcb\x02 \x01(\x0b\x32\x0b.api.FSLockH\x00\x12%\n\rfsReleaseLock\x18\xcc\x02 \x01(\x0b\x32\x0b.api.FSLockH\x00\x12\x11\n\x06hasCap\x18\xcf\x02 \x01(\x08H\x00\x12&\n\npid1Config\x18\xd4\x02 \x01(\x0b\x32\x0f.api.Pid1ConfigH\x00\x12 \n\x07metrics\x18\xde\x02 \x01(\x0b\x32\x0c.api.MetricsH\x00\x12&\n\nbootStatus\x18\xdf\x02 \x01(\x0b\x32\x0f.api.BootStatusH\x00\x12\"\n\x08readMeta\x18\xe8\x02 \x01(\x0b\x32\r.api.ReadMetaH\x00\x12$\n\twriteMeta\x18\xe9\x02 \x01(\x0b\x32\x0e.api.WriteMetaH\x00\x12&\n\nappendMeta\x18\xea\x02 \x01(\x0b\x32\x0f.api.AppendMetaH\x00\x12\x1c\n\x05\x61udio\x18\xeb\x02 \x01(\x0b\x32\n.api.AudioH\x00\x12\x0c\n\x03ref\x18\xe8\x07 \x01(\tB\x06\n\x04\x62odyJ\x06\x08\xfa\x01\x10\xfb\x01J\x06\x08\xfc\x01\x10\xfd\x01J\x06\x08\xfd\x01\x10\xfe\x01J\x06\x08\xfe\x01\x10\xff\x01J\x06\x08\xff\x01\x10\x80\x02\"\x15\n\x05\x41udio\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"5\n\x08ReadMeta\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06\x65xists\x18\x02 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"&\n\tWriteMeta\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\'\n\nAppendMeta\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xbe\x01\n\nBootStatus\x12$\n\x05stage\x18\x01 \x01(\x0e\x32\x15.api.BootStatus.Stage\x12\x10\n\x08progress\x18\x02 \x01(\r\x12\r\n\x05total\x18\x03 \x01(\r\"i\n\x05Stage\x12\r\n\tHANDSHAKE\x10\x00\x12\r\n\tACQUIRING\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05PROXY\x10\x05\x12\x0e\n\nPULL_FILES\x10\x06\x12\x0e\n\nLOAD_BLOCK\x10\x07\x12\t\n\x05RETRY\x10\x08\"+\n\nPid1Config\x12\x0b\n\x03\x63wd\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\"\x16\n\x06\x46SLock\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x0c\n\nFSSnapshot\")\n\rSubscribeFile\x12\x18\n\x05\x66iles\x18\x01 \x03(\x0b\x32\t.api.File\"\x90\x01\n\tFileEvent\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12\x17\n\x04\x64\x65st\x18\x03 \x01(\x0b\x32\t.api.File\x12\x1d\n\x02op\x18\x02 \x01(\x0e\x32\x11.api.FileEvent.Op\"2\n\x02Op\x12\n\n\x06\x43reate\x10\x00\x12\x08\n\x04Move\x10\x01\x12\n\n\x06Remove\x10\x02\x12\n\n\x06Modify\x10\x03\"\x07\n\x05\x46lush\"%\n\nOTLinkFile\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\"*\n\x04\x41uth\x12\r\n\x05token\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontainerID\x18\x02 \x01(\t\"\x93\x01\n\x08VCREntry\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12*\n\tdirection\x18\x02 \x01(\x0e\x32\x17.api.VCREntry.Direction\x12\x1d\n\x07\x63ommand\x18\x03 \x01(\x0b\x32\x0c.api.Command\x12\x0b\n\x03uid\x18\x04 \x01(\t\"\x1c\n\tDirection\x12\x06\n\x02IN\x10\x00\x12\x07\n\x03OUT\x10\x01\"\n\n\x08StartVCR\"\t\n\x07ReadVCR\"@\n\x06VCRLog\x12\x1a\n\x03log\x18\x01 \x03(\x0b\x32\r.api.VCREntry\x12\x1a\n\x07logfile\x18\x02 \x01(\x0b\x32\t.api.File\"+\n\x08\x45xecInfo\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x15\n\x05\x44\x65\x62ug\x12\x0c\n\x04text\x18\x01 \x01(\t\"K\n\x0b\x46ileAuthReq\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12#\n\x06method\x18\x02 \x01(\x0e\x32\x13.api.FileAuthMethod\"o\n\x10MultiFileAuthRes\x12\x1d\n\x03put\x18\x01 \x01(\x0b\x32\x10.api.FileAuthRes\x12\x1d\n\x03\x64\x65l\x18\x02 \x01(\x0b\x32\x10.api.FileAuthRes\x12\x1d\n\x03get\x18\x03 \x01(\x0b\x32\x10.api.FileAuthRes\"w\n\x0b\x46ileAuthRes\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.api.File\x12\x0b\n\x03url\x18\x02 \x01(\t\x12#\n\x06method\x18\x03 \x01(\x0e\x32\x13.api.FileAuthMethod\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"\x1d\n\x0bListObjects\x12\x0e\n\x06prefix\x18\x01 \x01(\t\"\"\n\x0fListObjectsResp\x12\x0f\n\x07objects\x18\x01 \x03(\t\"\x1b\n\nDisconnect\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x14\n\x04Send\x12\x0c\n\x04\x62uff\x18\x01 \x01(\x0c\"\x14\n\x04Recv\x12\x0c\n\x04\x62uff\x18\x01 \x01(\x0c\"&\n\x07\x43onnect\x12\r\n\x05proto\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\t\"\x14\n\x04Hint\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x06\n\x04Ping\"\x06\n\x04Pong\"8\n\x05Hello\x12\x0e\n\x06userid\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\"\t\n\x07Goodbye\"\x0e\n\x0c\x43heckChanges\":\n\x0e\x45nsurePackages\x12\x0f\n\x07install\x18\x01 \x01(\x08\x12\x17\n\x04\x66ile\x18\x02 \x01(\x0b\x32\t.api.File\"\x07\n\x05Start\";\n\x0b\x44\x65\x62ugStatus\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12\x1e\n\x05stack\x18\x02 \x03(\x0b\x32\x0f.api.StackFrame\",\n\nStackFrame\x12\x10\n\x08\x66unction\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\r\"E\n\rContainedTest\x12\x18\n\x05suite\x18\x01 \x01(\x0b\x32\t.api.File\x12\x1a\n\x07project\x18\x02 \x03(\x0b\x32\t.api.File\"M\n\nTestResult\x12\x0e\n\x06passed\x18\x01 \x01(\x08\x12\x0e\n\x06stderr\x18\x02 \x01(\t\x12\x1f\n\x05\x66\x61ils\x18\x03 \x03(\x0b\x32\x10.api.TestFailure\"*\n\x0bTestFailure\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05trace\x18\x02 \x01(\t\"(\n\nResizeTerm\x12\x0c\n\x04rows\x18\x01 \x01(\r\x12\x0c\n\x04\x63ols\x18\x02 \x01(\r\"\n\n\x08SaneTerm\"/\n\x0bLintResults\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.api.LintResult\"E\n\nLintResult\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03row\x18\x02 \x01(\x05\x12\x0e\n\x06\x63olumn\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\t\"\x04\n\x02OK\"(\n\x04Move\x12\x0f\n\x07oldPath\x18\x01 \x01(\t\x12\x0f\n\x07newPath\x18\x02 \x01(\t\"!\n\x05\x46iles\x12\x18\n\x05\x66iles\x18\x01 \x03(\x0b\x32\t.api.File\"g\n\x04\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x1c\n\x04type\x18\x02 \x01(\x0e\x32\x0e.api.File.Type\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"\"\n\x04Type\x12\x0b\n\x07REGULAR\x10\x00\x12\r\n\tDIRECTORY\x10\x01\"\x07\n\x05\x43lear\"\x15\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\"\t\n\x07RunMain\"\x99\x01\n\x0bOpenChannel\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x17.api.OpenChannel.Action\x12\n\n\x02id\x18\x04 \x01(\x05\"6\n\x06\x41\x63tion\x12\n\n\x06\x43REATE\x10\x00\x12\n\n\x06\x41TTACH\x10\x01\x12\x14\n\x10\x41TTACH_OR_CREATE\x10\x02\"\x84\x01\n\x0eOpenChannelRes\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.api.OpenChannelRes.State\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"-\n\x05State\x12\x0b\n\x07\x43REATED\x10\x00\x12\x0c\n\x08\x41TTACHED\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"x\n\x0c\x43loseChannel\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x18.api.CloseChannel.Action\"2\n\x06\x41\x63tion\x12\x0e\n\nDISCONNECT\x10\x00\x12\r\n\tTRY_CLOSE\x10\x01\x12\t\n\x05\x43LOSE\x10\x02\"|\n\x0f\x43loseChannelRes\x12\n\n\x02id\x18\x01 \x01(\x05\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.api.CloseChannelRes.Status\"0\n\x06Status\x12\x0e\n\nDISCONNECT\x10\x00\x12\t\n\x05\x43LOSE\x10\x01\x12\x0b\n\x07NOTHING\x10\x02\"Y\n\x0e\x43ontainerState\x12(\n\x05state\x18\x01 \x01(\x0e\x32\x19.api.ContainerState.State\"\x1d\n\x05State\x12\t\n\x05SLEEP\x10\x00\x12\t\n\x05READY\x10\x01\"<\n\x08PortOpen\x12\x11\n\tforwarded\x18\x01 \x01(\x08\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"8\n\x0eOTFetchRequest\x12\x13\n\x0bversionFrom\x18\x01 \x01(\r\x12\x11\n\tversionTo\x18\x02 \x01(\r\"1\n\x0fOTFetchResponse\x12\x1e\n\x07packets\x18\x01 \x03(\x0b\x32\r.api.OTPacket\"O\n\x08OTPacket\x12\x0f\n\x07version\x18\x01 \x01(\r\x12#\n\x03ops\x18\x02 \x03(\x0b\x32\x16.api.OTRuneTransformOp\x12\r\n\x05\x63rc32\x18\x03 \x01(\r\"M\n\x11OTRuneTransformOp\x12\x0e\n\x04skip\x18\x01 \x01(\rH\x00\x12\x10\n\x06\x64\x65lete\x18\x02 \x01(\rH\x00\x12\x10\n\x06insert\x18\x03 \x01(\tH\x00\x42\x04\n\x02op\"l\n\x08OTStatus\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x1d\n\nlinkedFile\x18\x03 \x01(\x0b\x32\t.api.File\x12\x1e\n\x07\x63ursors\x18\x04 \x03(\x0b\x32\r.api.OTCursor\"o\n\x08OTCursor\x12\x10\n\x08position\x18\x01 \x01(\r\x12\x16\n\x0eselectionStart\x18\x02 \x01(\r\x12\x14\n\x0cselectionEnd\x18\x03 \x01(\r\x12\x17\n\x04user\x18\x04 \x01(\x0b\x32\t.api.User\x12\n\n\x02id\x18\x05 \x01(\t\"-\n\x0b\x43hatMessage\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\".\n\nChatTyping\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0e\n\x06typing\x18\x02 \x01(\x08\"@\n\x04User\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05roles\x18\x03 \x03(\t\x12\x0f\n\x07session\x18\x04 \x01(\x05\"!\n\x06Roster\x12\x17\n\x04user\x18\x01 \x03(\x0b\x32\t.api.User\"s\n\x04\x45xec\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x1f\n\x03\x65nv\x18\x02 \x03(\x0b\x32\x12.api.Exec.EnvEntry\x12\x10\n\x08\x62locking\x18\x03 \x01(\x08\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xed\x01\n\x07Package\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04spec\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x13\n\x0bhomepageURL\x18\x0c \x01(\t\x12\x18\n\x10\x64ocumentationURL\x18\r \x01(\t\x12\x15\n\rsourceCodeURL\x18\x0e \x01(\t\x12\x15\n\rbugTrackerURL\x18\x0f \x01(\t\x12\x0e\n\x06\x61uthor\x18\x10 \x01(\t\x12\x0f\n\x07license\x18\x11 \x01(\t\x12\"\n\x0c\x64\x65pendencies\x18\x12 \x03(\x0b\x32\x0c.api.Package\"\x1e\n\rPackageSearch\x12\r\n\x05query\x18\x01 \x01(\t\"2\n\x11PackageSearchResp\x12\x1d\n\x07results\x18\x01 \x03(\x0b\x32\x0c.api.Package\"(\n\x0bPackageInfo\x12\x19\n\x03pkg\x18\x01 \x01(\x0b\x32\x0c.api.Package\",\n\x0fPackageInfoResp\x12\x19\n\x03pkg\x18\x01 \x01(\x0b\x32\x0c.api.Package\"(\n\nPackageAdd\x12\x1a\n\x04pkgs\x18\x01 \x03(\x0b\x32\x0c.api.Package\"+\n\rPackageRemove\x12\x1a\n\x04pkgs\x18\x01 \x03(\x0b\x32\x0c.api.Package\"\x10\n\x0ePackageInstall\"\x15\n\x13PackageListSpecfile\"5\n\x17PackageListSpecfileResp\x12\x1a\n\x04pkgs\x18\x01 \x03(\x0b\x32\x0c.api.Package\"\x12\n\x10PackageCacheSave\"6\n\x0e\x43hatScrollback\x12$\n\nscrollback\x18\x01 \x03(\x0b\x32\x10.api.ChatMessage\"+\n\x07Metrics\x12 \n\x18prometheusMetricFamilies\x18\x01 \x03(\x0c*8\n\x0e\x46ileAuthMethod\x12\x07\n\x03GET\x10\x00\x12\x08\n\x04HEAD\x10\x01\x12\x07\n\x03PUT\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03*!\n\x05State\x12\x0b\n\x07Stopped\x10\x00\x12\x0b\n\x07Running\x10\x01\x62\x06proto3'
)

_FILEAUTHMETHOD = _descriptor.EnumDescriptor(
  name='FileAuthMethod',
  full_name='api.FileAuthMethod',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8226,
  serialized_end=8282,
)
_sym_db.RegisterEnumDescriptor(_FILEAUTHMETHOD)

FileAuthMethod = enum_type_wrapper.EnumTypeWrapper(_FILEAUTHMETHOD)
_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='api.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Stopped', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Running', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8284,
  serialized_end=8317,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
GET = 0
HEAD = 1
PUT = 2
DELETE = 3
Stopped = 0
Running = 1


_BOOTSTATUS_STAGE = _descriptor.EnumDescriptor(
  name='Stage',
  full_name='api.BootStatus.Stage',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HANDSHAKE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACQUIRING', index=1, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXY', index=3, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PULL_FILES', index=4, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOAD_BLOCK', index=5, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETRY', index=6, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3845,
  serialized_end=3950,
)
_sym_db.RegisterEnumDescriptor(_BOOTSTATUS_STAGE)

_FILEEVENT_OP = _descriptor.EnumDescriptor(
  name='Op',
  full_name='api.FileEvent.Op',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Create', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Move', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Remove', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Modify', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4173,
  serialized_end=4223,
)
_sym_db.RegisterEnumDescriptor(_FILEEVENT_OP)

_VCRENTRY_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='api.VCREntry.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4437,
  serialized_end=4465,
)
_sym_db.RegisterEnumDescriptor(_VCRENTRY_DIRECTION)

_FILE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='api.File.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REGULAR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIRECTORY', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5934,
  serialized_end=5968,
)
_sym_db.RegisterEnumDescriptor(_FILE_TYPE)

_OPENCHANNEL_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='api.OpenChannel.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ATTACH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ATTACH_OR_CREATE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6113,
  serialized_end=6167,
)
_sym_db.RegisterEnumDescriptor(_OPENCHANNEL_ACTION)

_OPENCHANNELRES_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='api.OpenChannelRes.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ATTACHED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6257,
  serialized_end=6302,
)
_sym_db.RegisterEnumDescriptor(_OPENCHANNELRES_STATE)

_CLOSECHANNEL_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='api.CloseChannel.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISCONNECT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRY_CLOSE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLOSE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6374,
  serialized_end=6424,
)
_sym_db.RegisterEnumDescriptor(_CLOSECHANNEL_ACTION)

_CLOSECHANNELRES_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='api.CloseChannelRes.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISCONNECT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLOSE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOTHING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6502,
  serialized_end=6550,
)
_sym_db.RegisterEnumDescriptor(_CLOSECHANNELRES_STATUS)

_CONTAINERSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='api.ContainerState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SLEEP', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6612,
  serialized_end=6641,
)
_sym_db.RegisterEnumDescriptor(_CONTAINERSTATE_STATE)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='api.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='api.Command.channel', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session', full_name='api.Command.session', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='openChan', full_name='api.Command.openChan', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='openChanRes', full_name='api.Command.openChanRes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closeChan', full_name='api.Command.closeChan', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closeChanRes', full_name='api.Command.closeChanRes', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='containerState', full_name='api.Command.containerState', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portOpen', full_name='api.Command.portOpen', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toast', full_name='api.Command.toast', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runMain', full_name='api.Command.runMain', index=9,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clear', full_name='api.Command.clear', index=10,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eval', full_name='api.Command.eval', index=11,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='api.Command.result', index=12,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input', full_name='api.Command.input', index=13,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='api.Command.output', index=14,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='api.Command.error', index=15,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saneTerm', full_name='api.Command.saneTerm', index=16,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resizeTerm', full_name='api.Command.resizeTerm', index=17,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='api.Command.state', index=18,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ok', full_name='api.Command.ok', index=19,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persist', full_name='api.Command.persist', index=20,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistMirror', full_name='api.Command.persistMirror', index=21,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write', full_name='api.Command.write', index=22,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='api.Command.remove', index=23,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='move', full_name='api.Command.move', index=24,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tryRemove', full_name='api.Command.tryRemove', index=25,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mkdir', full_name='api.Command.mkdir', index=26,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read', full_name='api.Command.read', index=27,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readdir', full_name='api.Command.readdir', index=28,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='files', full_name='api.Command.files', index=29,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file', full_name='api.Command.file', index=30,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checkChanges', full_name='api.Command.checkChanges', index=31,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changedFiles', full_name='api.Command.changedFiles', index=32,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lintResults', full_name='api.Command.lintResults', index=33,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runContainedTest', full_name='api.Command.runContainedTest', index=34,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='testResult', full_name='api.Command.testResult', index=35,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debuggerStart', full_name='api.Command.debuggerStart', index=36,
      number=90, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debuggerStep', full_name='api.Command.debuggerStep', index=37,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debuggerStatus', full_name='api.Command.debuggerStatus', index=38,
      number=92, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ensurePackages', full_name='api.Command.ensurePackages', index=39,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ping', full_name='api.Command.ping', index=40,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pong', full_name='api.Command.pong', index=41,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hello', full_name='api.Command.hello', index=42,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goodbye', full_name='api.Command.goodbye', index=43,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hint', full_name='api.Command.hint', index=44,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connect', full_name='api.Command.connect', index=45,
      number=150, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send', full_name='api.Command.send', index=46,
      number=151, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recv', full_name='api.Command.recv', index=47,
      number=152, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disconnect', full_name='api.Command.disconnect', index=48,
      number=153, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileAuthReq', full_name='api.Command.fileAuthReq', index=49,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileAuthRes', full_name='api.Command.fileAuthRes', index=50,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mutliFileAuthRes', full_name='api.Command.mutliFileAuthRes', index=51,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listObjects', full_name='api.Command.listObjects', index=52,
      number=205, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listObjectsResp', full_name='api.Command.listObjectsResp', index=53,
      number=206, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ot', full_name='api.Command.ot', index=54,
      number=220, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otstatus', full_name='api.Command.otstatus', index=55,
      number=221, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otLinkFile', full_name='api.Command.otLinkFile', index=56,
      number=222, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otNewCursor', full_name='api.Command.otNewCursor', index=57,
      number=223, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otDeleteCursor', full_name='api.Command.otDeleteCursor', index=58,
      number=224, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otFetchRequest', full_name='api.Command.otFetchRequest', index=59,
      number=225, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otFetchResponse', full_name='api.Command.otFetchResponse', index=60,
      number=226, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flush', full_name='api.Command.flush', index=61,
      number=251, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug', full_name='api.Command.debug', index=62,
      number=230, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startVCR', full_name='api.Command.startVCR', index=63,
      number=231, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readVCR', full_name='api.Command.readVCR', index=64,
      number=232, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='VCRLog', full_name='api.Command.VCRLog', index=65,
      number=233, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth', full_name='api.Command.auth', index=66,
      number=235, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execInfo', full_name='api.Command.execInfo', index=67,
      number=240, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribeFile', full_name='api.Command.subscribeFile', index=68,
      number=256, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileEvent', full_name='api.Command.fileEvent', index=69,
      number=257, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roster', full_name='api.Command.roster', index=70,
      number=260, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join', full_name='api.Command.join', index=71,
      number=261, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='part', full_name='api.Command.part', index=72,
      number=262, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec', full_name='api.Command.exec', index=73,
      number=270, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageSearch', full_name='api.Command.packageSearch', index=74,
      number=280, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageSearchResp', full_name='api.Command.packageSearchResp', index=75,
      number=281, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageInfo', full_name='api.Command.packageInfo', index=76,
      number=282, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageInfoResp', full_name='api.Command.packageInfoResp', index=77,
      number=283, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageAdd', full_name='api.Command.packageAdd', index=78,
      number=284, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageRemove', full_name='api.Command.packageRemove', index=79,
      number=285, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageInstall', full_name='api.Command.packageInstall', index=80,
      number=286, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageListSpecfile', full_name='api.Command.packageListSpecfile', index=81,
      number=287, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageListSpecfileResp', full_name='api.Command.packageListSpecfileResp', index=82,
      number=288, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageCacheSave', full_name='api.Command.packageCacheSave', index=83,
      number=289, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatMessage', full_name='api.Command.chatMessage', index=84,
      number=310, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatTyping', full_name='api.Command.chatTyping', index=85,
      number=311, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatScrollback', full_name='api.Command.chatScrollback', index=86,
      number=312, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsSnapshot', full_name='api.Command.fsSnapshot', index=87,
      number=330, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsTakeLock', full_name='api.Command.fsTakeLock', index=88,
      number=331, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsReleaseLock', full_name='api.Command.fsReleaseLock', index=89,
      number=332, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasCap', full_name='api.Command.hasCap', index=90,
      number=335, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid1Config', full_name='api.Command.pid1Config', index=91,
      number=340, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='api.Command.metrics', index=92,
      number=350, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bootStatus', full_name='api.Command.bootStatus', index=93,
      number=351, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readMeta', full_name='api.Command.readMeta', index=94,
      number=360, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writeMeta', full_name='api.Command.writeMeta', index=95,
      number=361, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appendMeta', full_name='api.Command.appendMeta', index=96,
      number=362, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='api.Command.audio', index=97,
      number=363, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref', full_name='api.Command.ref', index=98,
      number=1000, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='api.Command.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=19,
  serialized_end=3598,
)


_AUDIO = _descriptor.Descriptor(
  name='Audio',
  full_name='api.Audio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.Audio.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3600,
  serialized_end=3621,
)


_READMETA = _descriptor.Descriptor(
  name='ReadMeta',
  full_name='api.ReadMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='api.ReadMeta.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exists', full_name='api.ReadMeta.exists', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='api.ReadMeta.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3623,
  serialized_end=3676,
)


_WRITEMETA = _descriptor.Descriptor(
  name='WriteMeta',
  full_name='api.WriteMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='api.WriteMeta.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='api.WriteMeta.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3716,
)


_APPENDMETA = _descriptor.Descriptor(
  name='AppendMeta',
  full_name='api.AppendMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='api.AppendMeta.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='api.AppendMeta.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3718,
  serialized_end=3757,
)


_BOOTSTATUS = _descriptor.Descriptor(
  name='BootStatus',
  full_name='api.BootStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stage', full_name='api.BootStatus.stage', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='progress', full_name='api.BootStatus.progress', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total', full_name='api.BootStatus.total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BOOTSTATUS_STAGE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3760,
  serialized_end=3950,
)


_PID1CONFIG = _descriptor.Descriptor(
  name='Pid1Config',
  full_name='api.Pid1Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cwd', full_name='api.Pid1Config.cwd', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='api.Pid1Config.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3952,
  serialized_end=3995,
)


_FSLOCK = _descriptor.Descriptor(
  name='FSLock',
  full_name='api.FSLock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='api.FSLock.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3997,
  serialized_end=4019,
)


_FSSNAPSHOT = _descriptor.Descriptor(
  name='FSSnapshot',
  full_name='api.FSSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4021,
  serialized_end=4033,
)


_SUBSCRIBEFILE = _descriptor.Descriptor(
  name='SubscribeFile',
  full_name='api.SubscribeFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='api.SubscribeFile.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4035,
  serialized_end=4076,
)


_FILEEVENT = _descriptor.Descriptor(
  name='FileEvent',
  full_name='api.FileEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='api.FileEvent.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dest', full_name='api.FileEvent.dest', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op', full_name='api.FileEvent.op', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILEEVENT_OP,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4079,
  serialized_end=4223,
)


_FLUSH = _descriptor.Descriptor(
  name='Flush',
  full_name='api.Flush',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4225,
  serialized_end=4232,
)


_OTLINKFILE = _descriptor.Descriptor(
  name='OTLinkFile',
  full_name='api.OTLinkFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='api.OTLinkFile.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4234,
  serialized_end=4271,
)


_AUTH = _descriptor.Descriptor(
  name='Auth',
  full_name='api.Auth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='api.Auth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='containerID', full_name='api.Auth.containerID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4273,
  serialized_end=4315,
)


_VCRENTRY = _descriptor.Descriptor(
  name='VCREntry',
  full_name='api.VCREntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='api.VCREntry.timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='api.VCREntry.direction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='api.VCREntry.command', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='api.VCREntry.uid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VCRENTRY_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4318,
  serialized_end=4465,
)


_STARTVCR = _descriptor.Descriptor(
  name='StartVCR',
  full_name='api.StartVCR',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4467,
  serialized_end=4477,
)


_READVCR = _descriptor.Descriptor(
  name='ReadVCR',
  full_name='api.ReadVCR',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4479,
  serialized_end=4488,
)


_VCRLOG = _descriptor.Descriptor(
  name='VCRLog',
  full_name='api.VCRLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='api.VCRLog.log', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logfile', full_name='api.VCRLog.logfile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4490,
  serialized_end=4554,
)


_EXECINFO = _descriptor.Descriptor(
  name='ExecInfo',
  full_name='api.ExecInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='api.ExecInfo.command', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='api.ExecInfo.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4556,
  serialized_end=4599,
)


_DEBUG = _descriptor.Descriptor(
  name='Debug',
  full_name='api.Debug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='api.Debug.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4601,
  serialized_end=4622,
)


_FILEAUTHREQ = _descriptor.Descriptor(
  name='FileAuthReq',
  full_name='api.FileAuthReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='api.FileAuthReq.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='api.FileAuthReq.method', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4624,
  serialized_end=4699,
)


_MULTIFILEAUTHRES = _descriptor.Descriptor(
  name='MultiFileAuthRes',
  full_name='api.MultiFileAuthRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='put', full_name='api.MultiFileAuthRes.put', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='del', full_name='api.MultiFileAuthRes.del', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get', full_name='api.MultiFileAuthRes.get', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4701,
  serialized_end=4812,
)


_FILEAUTHRES = _descriptor.Descriptor(
  name='FileAuthRes',
  full_name='api.FileAuthRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='api.FileAuthRes.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='api.FileAuthRes.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='api.FileAuthRes.method', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expire', full_name='api.FileAuthRes.expire', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='api.FileAuthRes.error', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4814,
  serialized_end=4933,
)


_LISTOBJECTS = _descriptor.Descriptor(
  name='ListObjects',
  full_name='api.ListObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='api.ListObjects.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4935,
  serialized_end=4964,
)


_LISTOBJECTSRESP = _descriptor.Descriptor(
  name='ListObjectsResp',
  full_name='api.ListObjectsResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='api.ListObjectsResp.objects', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4966,
  serialized_end=5000,
)


_DISCONNECT = _descriptor.Descriptor(
  name='Disconnect',
  full_name='api.Disconnect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='api.Disconnect.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5002,
  serialized_end=5029,
)


_SEND = _descriptor.Descriptor(
  name='Send',
  full_name='api.Send',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='buff', full_name='api.Send.buff', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5031,
  serialized_end=5051,
)


_RECV = _descriptor.Descriptor(
  name='Recv',
  full_name='api.Recv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='buff', full_name='api.Recv.buff', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5053,
  serialized_end=5073,
)


_CONNECT = _descriptor.Descriptor(
  name='Connect',
  full_name='api.Connect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proto', full_name='api.Connect.proto', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addr', full_name='api.Connect.addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5075,
  serialized_end=5113,
)


_HINT = _descriptor.Descriptor(
  name='Hint',
  full_name='api.Hint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='api.Hint.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5115,
  serialized_end=5135,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='api.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5137,
  serialized_end=5143,
)


_PONG = _descriptor.Descriptor(
  name='Pong',
  full_name='api.Pong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5145,
  serialized_end=5151,
)


_HELLO = _descriptor.Descriptor(
  name='Hello',
  full_name='api.Hello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userid', full_name='api.Hello.userid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='api.Hello.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='api.Hello.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5153,
  serialized_end=5209,
)


_GOODBYE = _descriptor.Descriptor(
  name='Goodbye',
  full_name='api.Goodbye',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5211,
  serialized_end=5220,
)


_CHECKCHANGES = _descriptor.Descriptor(
  name='CheckChanges',
  full_name='api.CheckChanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5222,
  serialized_end=5236,
)


_ENSUREPACKAGES = _descriptor.Descriptor(
  name='EnsurePackages',
  full_name='api.EnsurePackages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='install', full_name='api.EnsurePackages.install', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file', full_name='api.EnsurePackages.file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5238,
  serialized_end=5296,
)


_START = _descriptor.Descriptor(
  name='Start',
  full_name='api.Start',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5298,
  serialized_end=5305,
)


_DEBUGSTATUS = _descriptor.Descriptor(
  name='DebugStatus',
  full_name='api.DebugStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='done', full_name='api.DebugStatus.done', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stack', full_name='api.DebugStatus.stack', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5307,
  serialized_end=5366,
)


_STACKFRAME = _descriptor.Descriptor(
  name='StackFrame',
  full_name='api.StackFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='function', full_name='api.StackFrame.function', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='api.StackFrame.line', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5368,
  serialized_end=5412,
)


_CONTAINEDTEST = _descriptor.Descriptor(
  name='ContainedTest',
  full_name='api.ContainedTest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='suite', full_name='api.ContainedTest.suite', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='api.ContainedTest.project', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5414,
  serialized_end=5483,
)


_TESTRESULT = _descriptor.Descriptor(
  name='TestResult',
  full_name='api.TestResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='passed', full_name='api.TestResult.passed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stderr', full_name='api.TestResult.stderr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fails', full_name='api.TestResult.fails', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5485,
  serialized_end=5562,
)


_TESTFAILURE = _descriptor.Descriptor(
  name='TestFailure',
  full_name='api.TestFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='api.TestFailure.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='api.TestFailure.trace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5564,
  serialized_end=5606,
)


_RESIZETERM = _descriptor.Descriptor(
  name='ResizeTerm',
  full_name='api.ResizeTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='api.ResizeTerm.rows', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cols', full_name='api.ResizeTerm.cols', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5608,
  serialized_end=5648,
)


_SANETERM = _descriptor.Descriptor(
  name='SaneTerm',
  full_name='api.SaneTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5650,
  serialized_end=5660,
)


_LINTRESULTS = _descriptor.Descriptor(
  name='LintResults',
  full_name='api.LintResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='api.LintResults.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5662,
  serialized_end=5709,
)


_LINTRESULT = _descriptor.Descriptor(
  name='LintResult',
  full_name='api.LintResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='api.LintResult.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='api.LintResult.row', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='api.LintResult.column', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='api.LintResult.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5711,
  serialized_end=5780,
)


_OK = _descriptor.Descriptor(
  name='OK',
  full_name='api.OK',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5782,
  serialized_end=5786,
)


_MOVE = _descriptor.Descriptor(
  name='Move',
  full_name='api.Move',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='oldPath', full_name='api.Move.oldPath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newPath', full_name='api.Move.newPath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5788,
  serialized_end=5828,
)


_FILES = _descriptor.Descriptor(
  name='Files',
  full_name='api.Files',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='api.Files.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5830,
  serialized_end=5863,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='api.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='api.File.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='api.File.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='api.File.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5865,
  serialized_end=5968,
)


_CLEAR = _descriptor.Descriptor(
  name='Clear',
  full_name='api.Clear',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5970,
  serialized_end=5977,
)


_TOAST = _descriptor.Descriptor(
  name='Toast',
  full_name='api.Toast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='api.Toast.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5979,
  serialized_end=6000,
)


_RUNMAIN = _descriptor.Descriptor(
  name='RunMain',
  full_name='api.RunMain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6002,
  serialized_end=6011,
)


_OPENCHANNEL = _descriptor.Descriptor(
  name='OpenChannel',
  full_name='api.OpenChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='api.OpenChannel.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='api.OpenChannel.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='api.OpenChannel.action', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='api.OpenChannel.id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENCHANNEL_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6014,
  serialized_end=6167,
)


_OPENCHANNELRES = _descriptor.Descriptor(
  name='OpenChannelRes',
  full_name='api.OpenChannelRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.OpenChannelRes.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='api.OpenChannelRes.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='api.OpenChannelRes.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENCHANNELRES_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6170,
  serialized_end=6302,
)


_CLOSECHANNEL = _descriptor.Descriptor(
  name='CloseChannel',
  full_name='api.CloseChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.CloseChannel.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='api.CloseChannel.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLOSECHANNEL_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6304,
  serialized_end=6424,
)


_CLOSECHANNELRES = _descriptor.Descriptor(
  name='CloseChannelRes',
  full_name='api.CloseChannelRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.CloseChannelRes.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='api.CloseChannelRes.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLOSECHANNELRES_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6426,
  serialized_end=6550,
)


_CONTAINERSTATE = _descriptor.Descriptor(
  name='ContainerState',
  full_name='api.ContainerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='api.ContainerState.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTAINERSTATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6552,
  serialized_end=6641,
)


_PORTOPEN = _descriptor.Descriptor(
  name='PortOpen',
  full_name='api.PortOpen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forwarded', full_name='api.PortOpen.forwarded', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='api.PortOpen.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='api.PortOpen.address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6643,
  serialized_end=6703,
)


_OTFETCHREQUEST = _descriptor.Descriptor(
  name='OTFetchRequest',
  full_name='api.OTFetchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='versionFrom', full_name='api.OTFetchRequest.versionFrom', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionTo', full_name='api.OTFetchRequest.versionTo', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6705,
  serialized_end=6761,
)


_OTFETCHRESPONSE = _descriptor.Descriptor(
  name='OTFetchResponse',
  full_name='api.OTFetchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packets', full_name='api.OTFetchResponse.packets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6763,
  serialized_end=6812,
)


_OTPACKET = _descriptor.Descriptor(
  name='OTPacket',
  full_name='api.OTPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='api.OTPacket.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ops', full_name='api.OTPacket.ops', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc32', full_name='api.OTPacket.crc32', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6814,
  serialized_end=6893,
)


_OTRUNETRANSFORMOP = _descriptor.Descriptor(
  name='OTRuneTransformOp',
  full_name='api.OTRuneTransformOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip', full_name='api.OTRuneTransformOp.skip', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete', full_name='api.OTRuneTransformOp.delete', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert', full_name='api.OTRuneTransformOp.insert', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='op', full_name='api.OTRuneTransformOp.op',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6895,
  serialized_end=6972,
)


_OTSTATUS = _descriptor.Descriptor(
  name='OTStatus',
  full_name='api.OTStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contents', full_name='api.OTStatus.contents', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='api.OTStatus.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkedFile', full_name='api.OTStatus.linkedFile', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cursors', full_name='api.OTStatus.cursors', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6974,
  serialized_end=7082,
)


_OTCURSOR = _descriptor.Descriptor(
  name='OTCursor',
  full_name='api.OTCursor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='api.OTCursor.position', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectionStart', full_name='api.OTCursor.selectionStart', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectionEnd', full_name='api.OTCursor.selectionEnd', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='api.OTCursor.user', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='api.OTCursor.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7084,
  serialized_end=7195,
)


_CHATMESSAGE = _descriptor.Descriptor(
  name='ChatMessage',
  full_name='api.ChatMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='api.ChatMessage.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='api.ChatMessage.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7197,
  serialized_end=7242,
)


_CHATTYPING = _descriptor.Descriptor(
  name='ChatTyping',
  full_name='api.ChatTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='api.ChatTyping.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='typing', full_name='api.ChatTyping.typing', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7244,
  serialized_end=7290,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='api.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.User.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='api.User.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roles', full_name='api.User.roles', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session', full_name='api.User.session', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7292,
  serialized_end=7356,
)


_ROSTER = _descriptor.Descriptor(
  name='Roster',
  full_name='api.Roster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='api.Roster.user', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7358,
  serialized_end=7391,
)


_EXEC_ENVENTRY = _descriptor.Descriptor(
  name='EnvEntry',
  full_name='api.Exec.EnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='api.Exec.EnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='api.Exec.EnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7466,
  serialized_end=7508,
)

_EXEC = _descriptor.Descriptor(
  name='Exec',
  full_name='api.Exec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='api.Exec.args', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env', full_name='api.Exec.env', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blocking', full_name='api.Exec.blocking', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EXEC_ENVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7393,
  serialized_end=7508,
)


_PACKAGE = _descriptor.Descriptor(
  name='Package',
  full_name='api.Package',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='api.Package.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='api.Package.spec', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='api.Package.description', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='api.Package.version', index=3,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='homepageURL', full_name='api.Package.homepageURL', index=4,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='documentationURL', full_name='api.Package.documentationURL', index=5,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceCodeURL', full_name='api.Package.sourceCodeURL', index=6,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bugTrackerURL', full_name='api.Package.bugTrackerURL', index=7,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author', full_name='api.Package.author', index=8,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='license', full_name='api.Package.license', index=9,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='api.Package.dependencies', index=10,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7511,
  serialized_end=7748,
)


_PACKAGESEARCH = _descriptor.Descriptor(
  name='PackageSearch',
  full_name='api.PackageSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='api.PackageSearch.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7750,
  serialized_end=7780,
)


_PACKAGESEARCHRESP = _descriptor.Descriptor(
  name='PackageSearchResp',
  full_name='api.PackageSearchResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='api.PackageSearchResp.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7782,
  serialized_end=7832,
)


_PACKAGEINFO = _descriptor.Descriptor(
  name='PackageInfo',
  full_name='api.PackageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkg', full_name='api.PackageInfo.pkg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7834,
  serialized_end=7874,
)


_PACKAGEINFORESP = _descriptor.Descriptor(
  name='PackageInfoResp',
  full_name='api.PackageInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkg', full_name='api.PackageInfoResp.pkg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7876,
  serialized_end=7920,
)


_PACKAGEADD = _descriptor.Descriptor(
  name='PackageAdd',
  full_name='api.PackageAdd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkgs', full_name='api.PackageAdd.pkgs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7922,
  serialized_end=7962,
)


_PACKAGEREMOVE = _descriptor.Descriptor(
  name='PackageRemove',
  full_name='api.PackageRemove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkgs', full_name='api.PackageRemove.pkgs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7964,
  serialized_end=8007,
)


_PACKAGEINSTALL = _descriptor.Descriptor(
  name='PackageInstall',
  full_name='api.PackageInstall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8009,
  serialized_end=8025,
)


_PACKAGELISTSPECFILE = _descriptor.Descriptor(
  name='PackageListSpecfile',
  full_name='api.PackageListSpecfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8027,
  serialized_end=8048,
)


_PACKAGELISTSPECFILERESP = _descriptor.Descriptor(
  name='PackageListSpecfileResp',
  full_name='api.PackageListSpecfileResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkgs', full_name='api.PackageListSpecfileResp.pkgs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8050,
  serialized_end=8103,
)


_PACKAGECACHESAVE = _descriptor.Descriptor(
  name='PackageCacheSave',
  full_name='api.PackageCacheSave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8105,
  serialized_end=8123,
)


_CHATSCROLLBACK = _descriptor.Descriptor(
  name='ChatScrollback',
  full_name='api.ChatScrollback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scrollback', full_name='api.ChatScrollback.scrollback', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8125,
  serialized_end=8179,
)


_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='api.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prometheusMetricFamilies', full_name='api.Metrics.prometheusMetricFamilies', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8181,
  serialized_end=8224,
)

_COMMAND.fields_by_name['openChan'].message_type = _OPENCHANNEL
_COMMAND.fields_by_name['openChanRes'].message_type = _OPENCHANNELRES
_COMMAND.fields_by_name['closeChan'].message_type = _CLOSECHANNEL
_COMMAND.fields_by_name['closeChanRes'].message_type = _CLOSECHANNELRES
_COMMAND.fields_by_name['containerState'].message_type = _CONTAINERSTATE
_COMMAND.fields_by_name['portOpen'].message_type = _PORTOPEN
_COMMAND.fields_by_name['toast'].message_type = _TOAST
_COMMAND.fields_by_name['runMain'].message_type = _RUNMAIN
_COMMAND.fields_by_name['clear'].message_type = _CLEAR
_COMMAND.fields_by_name['saneTerm'].message_type = _SANETERM
_COMMAND.fields_by_name['resizeTerm'].message_type = _RESIZETERM
_COMMAND.fields_by_name['state'].enum_type = _STATE
_COMMAND.fields_by_name['ok'].message_type = _OK
_COMMAND.fields_by_name['persist'].message_type = _FILE
_COMMAND.fields_by_name['persistMirror'].message_type = _FILE
_COMMAND.fields_by_name['write'].message_type = _FILE
_COMMAND.fields_by_name['remove'].message_type = _FILE
_COMMAND.fields_by_name['move'].message_type = _MOVE
_COMMAND.fields_by_name['tryRemove'].message_type = _FILE
_COMMAND.fields_by_name['mkdir'].message_type = _FILE
_COMMAND.fields_by_name['read'].message_type = _FILE
_COMMAND.fields_by_name['readdir'].message_type = _FILE
_COMMAND.fields_by_name['files'].message_type = _FILES
_COMMAND.fields_by_name['file'].message_type = _FILE
_COMMAND.fields_by_name['checkChanges'].message_type = _CHECKCHANGES
_COMMAND.fields_by_name['changedFiles'].message_type = _FILES
_COMMAND.fields_by_name['lintResults'].message_type = _LINTRESULTS
_COMMAND.fields_by_name['runContainedTest'].message_type = _CONTAINEDTEST
_COMMAND.fields_by_name['testResult'].message_type = _TESTRESULT
_COMMAND.fields_by_name['debuggerStep'].message_type = _RUNMAIN
_COMMAND.fields_by_name['debuggerStatus'].message_type = _DEBUGSTATUS
_COMMAND.fields_by_name['ensurePackages'].message_type = _ENSUREPACKAGES
_COMMAND.fields_by_name['ping'].message_type = _PING
_COMMAND.fields_by_name['pong'].message_type = _PONG
_COMMAND.fields_by_name['hello'].message_type = _HELLO
_COMMAND.fields_by_name['goodbye'].message_type = _GOODBYE
_COMMAND.fields_by_name['hint'].message_type = _HINT
_COMMAND.fields_by_name['connect'].message_type = _CONNECT
_COMMAND.fields_by_name['send'].message_type = _SEND
_COMMAND.fields_by_name['recv'].message_type = _RECV
_COMMAND.fields_by_name['disconnect'].message_type = _DISCONNECT
_COMMAND.fields_by_name['fileAuthReq'].message_type = _FILEAUTHREQ
_COMMAND.fields_by_name['fileAuthRes'].message_type = _FILEAUTHRES
_COMMAND.fields_by_name['mutliFileAuthRes'].message_type = _MULTIFILEAUTHRES
_COMMAND.fields_by_name['listObjects'].message_type = _LISTOBJECTS
_COMMAND.fields_by_name['listObjectsResp'].message_type = _LISTOBJECTSRESP
_COMMAND.fields_by_name['ot'].message_type = _OTPACKET
_COMMAND.fields_by_name['otstatus'].message_type = _OTSTATUS
_COMMAND.fields_by_name['otLinkFile'].message_type = _OTLINKFILE
_COMMAND.fields_by_name['otNewCursor'].message_type = _OTCURSOR
_COMMAND.fields_by_name['otDeleteCursor'].message_type = _OTCURSOR
_COMMAND.fields_by_name['otFetchRequest'].message_type = _OTFETCHREQUEST
_COMMAND.fields_by_name['otFetchResponse'].message_type = _OTFETCHRESPONSE
_COMMAND.fields_by_name['flush'].message_type = _FLUSH
_COMMAND.fields_by_name['debug'].message_type = _DEBUG
_COMMAND.fields_by_name['startVCR'].message_type = _STARTVCR
_COMMAND.fields_by_name['readVCR'].message_type = _READVCR
_COMMAND.fields_by_name['VCRLog'].message_type = _VCRLOG
_COMMAND.fields_by_name['auth'].message_type = _AUTH
_COMMAND.fields_by_name['execInfo'].message_type = _EXECINFO
_COMMAND.fields_by_name['subscribeFile'].message_type = _SUBSCRIBEFILE
_COMMAND.fields_by_name['fileEvent'].message_type = _FILEEVENT
_COMMAND.fields_by_name['roster'].message_type = _ROSTER
_COMMAND.fields_by_name['join'].message_type = _USER
_COMMAND.fields_by_name['part'].message_type = _USER
_COMMAND.fields_by_name['exec'].message_type = _EXEC
_COMMAND.fields_by_name['packageSearch'].message_type = _PACKAGESEARCH
_COMMAND.fields_by_name['packageSearchResp'].message_type = _PACKAGESEARCHRESP
_COMMAND.fields_by_name['packageInfo'].message_type = _PACKAGEINFO
_COMMAND.fields_by_name['packageInfoResp'].message_type = _PACKAGEINFORESP
_COMMAND.fields_by_name['packageAdd'].message_type = _PACKAGEADD
_COMMAND.fields_by_name['packageRemove'].message_type = _PACKAGEREMOVE
_COMMAND.fields_by_name['packageInstall'].message_type = _PACKAGEINSTALL
_COMMAND.fields_by_name['packageListSpecfile'].message_type = _PACKAGELISTSPECFILE
_COMMAND.fields_by_name['packageListSpecfileResp'].message_type = _PACKAGELISTSPECFILERESP
_COMMAND.fields_by_name['packageCacheSave'].message_type = _PACKAGECACHESAVE
_COMMAND.fields_by_name['chatMessage'].message_type = _CHATMESSAGE
_COMMAND.fields_by_name['chatTyping'].message_type = _CHATTYPING
_COMMAND.fields_by_name['chatScrollback'].message_type = _CHATSCROLLBACK
_COMMAND.fields_by_name['fsSnapshot'].message_type = _FSSNAPSHOT
_COMMAND.fields_by_name['fsTakeLock'].message_type = _FSLOCK
_COMMAND.fields_by_name['fsReleaseLock'].message_type = _FSLOCK
_COMMAND.fields_by_name['pid1Config'].message_type = _PID1CONFIG
_COMMAND.fields_by_name['metrics'].message_type = _METRICS
_COMMAND.fields_by_name['bootStatus'].message_type = _BOOTSTATUS
_COMMAND.fields_by_name['readMeta'].message_type = _READMETA
_COMMAND.fields_by_name['writeMeta'].message_type = _WRITEMETA
_COMMAND.fields_by_name['appendMeta'].message_type = _APPENDMETA
_COMMAND.fields_by_name['audio'].message_type = _AUDIO
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['openChan'])
_COMMAND.fields_by_name['openChan'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['openChanRes'])
_COMMAND.fields_by_name['openChanRes'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['closeChan'])
_COMMAND.fields_by_name['closeChan'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['closeChanRes'])
_COMMAND.fields_by_name['closeChanRes'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['containerState'])
_COMMAND.fields_by_name['containerState'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['portOpen'])
_COMMAND.fields_by_name['portOpen'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['toast'])
_COMMAND.fields_by_name['toast'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['runMain'])
_COMMAND.fields_by_name['runMain'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['clear'])
_COMMAND.fields_by_name['clear'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['eval'])
_COMMAND.fields_by_name['eval'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['result'])
_COMMAND.fields_by_name['result'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['input'])
_COMMAND.fields_by_name['input'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['output'])
_COMMAND.fields_by_name['output'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['error'])
_COMMAND.fields_by_name['error'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['saneTerm'])
_COMMAND.fields_by_name['saneTerm'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['resizeTerm'])
_COMMAND.fields_by_name['resizeTerm'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['state'])
_COMMAND.fields_by_name['state'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['ok'])
_COMMAND.fields_by_name['ok'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['persist'])
_COMMAND.fields_by_name['persist'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['persistMirror'])
_COMMAND.fields_by_name['persistMirror'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['write'])
_COMMAND.fields_by_name['write'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['remove'])
_COMMAND.fields_by_name['remove'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['move'])
_COMMAND.fields_by_name['move'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['tryRemove'])
_COMMAND.fields_by_name['tryRemove'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['mkdir'])
_COMMAND.fields_by_name['mkdir'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['read'])
_COMMAND.fields_by_name['read'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['readdir'])
_COMMAND.fields_by_name['readdir'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['files'])
_COMMAND.fields_by_name['files'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['file'])
_COMMAND.fields_by_name['file'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['checkChanges'])
_COMMAND.fields_by_name['checkChanges'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['changedFiles'])
_COMMAND.fields_by_name['changedFiles'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['lintResults'])
_COMMAND.fields_by_name['lintResults'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['runContainedTest'])
_COMMAND.fields_by_name['runContainedTest'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['testResult'])
_COMMAND.fields_by_name['testResult'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['debuggerStart'])
_COMMAND.fields_by_name['debuggerStart'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['debuggerStep'])
_COMMAND.fields_by_name['debuggerStep'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['debuggerStatus'])
_COMMAND.fields_by_name['debuggerStatus'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['ensurePackages'])
_COMMAND.fields_by_name['ensurePackages'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['ping'])
_COMMAND.fields_by_name['ping'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['pong'])
_COMMAND.fields_by_name['pong'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['hello'])
_COMMAND.fields_by_name['hello'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['goodbye'])
_COMMAND.fields_by_name['goodbye'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['hint'])
_COMMAND.fields_by_name['hint'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['connect'])
_COMMAND.fields_by_name['connect'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['send'])
_COMMAND.fields_by_name['send'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['recv'])
_COMMAND.fields_by_name['recv'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['disconnect'])
_COMMAND.fields_by_name['disconnect'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['fileAuthReq'])
_COMMAND.fields_by_name['fileAuthReq'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['fileAuthRes'])
_COMMAND.fields_by_name['fileAuthRes'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['mutliFileAuthRes'])
_COMMAND.fields_by_name['mutliFileAuthRes'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['listObjects'])
_COMMAND.fields_by_name['listObjects'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['listObjectsResp'])
_COMMAND.fields_by_name['listObjectsResp'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['ot'])
_COMMAND.fields_by_name['ot'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['otstatus'])
_COMMAND.fields_by_name['otstatus'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['otLinkFile'])
_COMMAND.fields_by_name['otLinkFile'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['otNewCursor'])
_COMMAND.fields_by_name['otNewCursor'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['otDeleteCursor'])
_COMMAND.fields_by_name['otDeleteCursor'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['otFetchRequest'])
_COMMAND.fields_by_name['otFetchRequest'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['otFetchResponse'])
_COMMAND.fields_by_name['otFetchResponse'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['flush'])
_COMMAND.fields_by_name['flush'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['debug'])
_COMMAND.fields_by_name['debug'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['startVCR'])
_COMMAND.fields_by_name['startVCR'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['readVCR'])
_COMMAND.fields_by_name['readVCR'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['VCRLog'])
_COMMAND.fields_by_name['VCRLog'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['auth'])
_COMMAND.fields_by_name['auth'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['execInfo'])
_COMMAND.fields_by_name['execInfo'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['subscribeFile'])
_COMMAND.fields_by_name['subscribeFile'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['fileEvent'])
_COMMAND.fields_by_name['fileEvent'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['roster'])
_COMMAND.fields_by_name['roster'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['join'])
_COMMAND.fields_by_name['join'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['part'])
_COMMAND.fields_by_name['part'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['exec'])
_COMMAND.fields_by_name['exec'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageSearch'])
_COMMAND.fields_by_name['packageSearch'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageSearchResp'])
_COMMAND.fields_by_name['packageSearchResp'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageInfo'])
_COMMAND.fields_by_name['packageInfo'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageInfoResp'])
_COMMAND.fields_by_name['packageInfoResp'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageAdd'])
_COMMAND.fields_by_name['packageAdd'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageRemove'])
_COMMAND.fields_by_name['packageRemove'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageInstall'])
_COMMAND.fields_by_name['packageInstall'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageListSpecfile'])
_COMMAND.fields_by_name['packageListSpecfile'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageListSpecfileResp'])
_COMMAND.fields_by_name['packageListSpecfileResp'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['packageCacheSave'])
_COMMAND.fields_by_name['packageCacheSave'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['chatMessage'])
_COMMAND.fields_by_name['chatMessage'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['chatTyping'])
_COMMAND.fields_by_name['chatTyping'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['chatScrollback'])
_COMMAND.fields_by_name['chatScrollback'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['fsSnapshot'])
_COMMAND.fields_by_name['fsSnapshot'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['fsTakeLock'])
_COMMAND.fields_by_name['fsTakeLock'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['fsReleaseLock'])
_COMMAND.fields_by_name['fsReleaseLock'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['hasCap'])
_COMMAND.fields_by_name['hasCap'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['pid1Config'])
_COMMAND.fields_by_name['pid1Config'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['metrics'])
_COMMAND.fields_by_name['metrics'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['bootStatus'])
_COMMAND.fields_by_name['bootStatus'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['readMeta'])
_COMMAND.fields_by_name['readMeta'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['writeMeta'])
_COMMAND.fields_by_name['writeMeta'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['appendMeta'])
_COMMAND.fields_by_name['appendMeta'].containing_oneof = _COMMAND.oneofs_by_name['body']
_COMMAND.oneofs_by_name['body'].fields.append(
  _COMMAND.fields_by_name['audio'])
_COMMAND.fields_by_name['audio'].containing_oneof = _COMMAND.oneofs_by_name['body']
_BOOTSTATUS.fields_by_name['stage'].enum_type = _BOOTSTATUS_STAGE
_BOOTSTATUS_STAGE.containing_type = _BOOTSTATUS
_SUBSCRIBEFILE.fields_by_name['files'].message_type = _FILE
_FILEEVENT.fields_by_name['file'].message_type = _FILE
_FILEEVENT.fields_by_name['dest'].message_type = _FILE
_FILEEVENT.fields_by_name['op'].enum_type = _FILEEVENT_OP
_FILEEVENT_OP.containing_type = _FILEEVENT
_OTLINKFILE.fields_by_name['file'].message_type = _FILE
_VCRENTRY.fields_by_name['direction'].enum_type = _VCRENTRY_DIRECTION
_VCRENTRY.fields_by_name['command'].message_type = _COMMAND
_VCRENTRY_DIRECTION.containing_type = _VCRENTRY
_VCRLOG.fields_by_name['log'].message_type = _VCRENTRY
_VCRLOG.fields_by_name['logfile'].message_type = _FILE
_FILEAUTHREQ.fields_by_name['file'].message_type = _FILE
_FILEAUTHREQ.fields_by_name['method'].enum_type = _FILEAUTHMETHOD
_MULTIFILEAUTHRES.fields_by_name['put'].message_type = _FILEAUTHRES
_MULTIFILEAUTHRES.fields_by_name['del'].message_type = _FILEAUTHRES
_MULTIFILEAUTHRES.fields_by_name['get'].message_type = _FILEAUTHRES
_FILEAUTHRES.fields_by_name['file'].message_type = _FILE
_FILEAUTHRES.fields_by_name['method'].enum_type = _FILEAUTHMETHOD
_ENSUREPACKAGES.fields_by_name['file'].message_type = _FILE
_DEBUGSTATUS.fields_by_name['stack'].message_type = _STACKFRAME
_CONTAINEDTEST.fields_by_name['suite'].message_type = _FILE
_CONTAINEDTEST.fields_by_name['project'].message_type = _FILE
_TESTRESULT.fields_by_name['fails'].message_type = _TESTFAILURE
_LINTRESULTS.fields_by_name['results'].message_type = _LINTRESULT
_FILES.fields_by_name['files'].message_type = _FILE
_FILE.fields_by_name['type'].enum_type = _FILE_TYPE
_FILE_TYPE.containing_type = _FILE
_OPENCHANNEL.fields_by_name['action'].enum_type = _OPENCHANNEL_ACTION
_OPENCHANNEL_ACTION.containing_type = _OPENCHANNEL
_OPENCHANNELRES.fields_by_name['state'].enum_type = _OPENCHANNELRES_STATE
_OPENCHANNELRES_STATE.containing_type = _OPENCHANNELRES
_CLOSECHANNEL.fields_by_name['action'].enum_type = _CLOSECHANNEL_ACTION
_CLOSECHANNEL_ACTION.containing_type = _CLOSECHANNEL
_CLOSECHANNELRES.fields_by_name['status'].enum_type = _CLOSECHANNELRES_STATUS
_CLOSECHANNELRES_STATUS.containing_type = _CLOSECHANNELRES
_CONTAINERSTATE.fields_by_name['state'].enum_type = _CONTAINERSTATE_STATE
_CONTAINERSTATE_STATE.containing_type = _CONTAINERSTATE
_OTFETCHRESPONSE.fields_by_name['packets'].message_type = _OTPACKET
_OTPACKET.fields_by_name['ops'].message_type = _OTRUNETRANSFORMOP
_OTRUNETRANSFORMOP.oneofs_by_name['op'].fields.append(
  _OTRUNETRANSFORMOP.fields_by_name['skip'])
_OTRUNETRANSFORMOP.fields_by_name['skip'].containing_oneof = _OTRUNETRANSFORMOP.oneofs_by_name['op']
_OTRUNETRANSFORMOP.oneofs_by_name['op'].fields.append(
  _OTRUNETRANSFORMOP.fields_by_name['delete'])
_OTRUNETRANSFORMOP.fields_by_name['delete'].containing_oneof = _OTRUNETRANSFORMOP.oneofs_by_name['op']
_OTRUNETRANSFORMOP.oneofs_by_name['op'].fields.append(
  _OTRUNETRANSFORMOP.fields_by_name['insert'])
_OTRUNETRANSFORMOP.fields_by_name['insert'].containing_oneof = _OTRUNETRANSFORMOP.oneofs_by_name['op']
_OTSTATUS.fields_by_name['linkedFile'].message_type = _FILE
_OTSTATUS.fields_by_name['cursors'].message_type = _OTCURSOR
_OTCURSOR.fields_by_name['user'].message_type = _USER
_ROSTER.fields_by_name['user'].message_type = _USER
_EXEC_ENVENTRY.containing_type = _EXEC
_EXEC.fields_by_name['env'].message_type = _EXEC_ENVENTRY
_PACKAGE.fields_by_name['dependencies'].message_type = _PACKAGE
_PACKAGESEARCHRESP.fields_by_name['results'].message_type = _PACKAGE
_PACKAGEINFO.fields_by_name['pkg'].message_type = _PACKAGE
_PACKAGEINFORESP.fields_by_name['pkg'].message_type = _PACKAGE
_PACKAGEADD.fields_by_name['pkgs'].message_type = _PACKAGE
_PACKAGEREMOVE.fields_by_name['pkgs'].message_type = _PACKAGE
_PACKAGELISTSPECFILERESP.fields_by_name['pkgs'].message_type = _PACKAGE
_CHATSCROLLBACK.fields_by_name['scrollback'].message_type = _CHATMESSAGE
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['Audio'] = _AUDIO
DESCRIPTOR.message_types_by_name['ReadMeta'] = _READMETA
DESCRIPTOR.message_types_by_name['WriteMeta'] = _WRITEMETA
DESCRIPTOR.message_types_by_name['AppendMeta'] = _APPENDMETA
DESCRIPTOR.message_types_by_name['BootStatus'] = _BOOTSTATUS
DESCRIPTOR.message_types_by_name['Pid1Config'] = _PID1CONFIG
DESCRIPTOR.message_types_by_name['FSLock'] = _FSLOCK
DESCRIPTOR.message_types_by_name['FSSnapshot'] = _FSSNAPSHOT
DESCRIPTOR.message_types_by_name['SubscribeFile'] = _SUBSCRIBEFILE
DESCRIPTOR.message_types_by_name['FileEvent'] = _FILEEVENT
DESCRIPTOR.message_types_by_name['Flush'] = _FLUSH
DESCRIPTOR.message_types_by_name['OTLinkFile'] = _OTLINKFILE
DESCRIPTOR.message_types_by_name['Auth'] = _AUTH
DESCRIPTOR.message_types_by_name['VCREntry'] = _VCRENTRY
DESCRIPTOR.message_types_by_name['StartVCR'] = _STARTVCR
DESCRIPTOR.message_types_by_name['ReadVCR'] = _READVCR
DESCRIPTOR.message_types_by_name['VCRLog'] = _VCRLOG
DESCRIPTOR.message_types_by_name['ExecInfo'] = _EXECINFO
DESCRIPTOR.message_types_by_name['Debug'] = _DEBUG
DESCRIPTOR.message_types_by_name['FileAuthReq'] = _FILEAUTHREQ
DESCRIPTOR.message_types_by_name['MultiFileAuthRes'] = _MULTIFILEAUTHRES
DESCRIPTOR.message_types_by_name['FileAuthRes'] = _FILEAUTHRES
DESCRIPTOR.message_types_by_name['ListObjects'] = _LISTOBJECTS
DESCRIPTOR.message_types_by_name['ListObjectsResp'] = _LISTOBJECTSRESP
DESCRIPTOR.message_types_by_name['Disconnect'] = _DISCONNECT
DESCRIPTOR.message_types_by_name['Send'] = _SEND
DESCRIPTOR.message_types_by_name['Recv'] = _RECV
DESCRIPTOR.message_types_by_name['Connect'] = _CONNECT
DESCRIPTOR.message_types_by_name['Hint'] = _HINT
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Pong'] = _PONG
DESCRIPTOR.message_types_by_name['Hello'] = _HELLO
DESCRIPTOR.message_types_by_name['Goodbye'] = _GOODBYE
DESCRIPTOR.message_types_by_name['CheckChanges'] = _CHECKCHANGES
DESCRIPTOR.message_types_by_name['EnsurePackages'] = _ENSUREPACKAGES
DESCRIPTOR.message_types_by_name['Start'] = _START
DESCRIPTOR.message_types_by_name['DebugStatus'] = _DEBUGSTATUS
DESCRIPTOR.message_types_by_name['StackFrame'] = _STACKFRAME
DESCRIPTOR.message_types_by_name['ContainedTest'] = _CONTAINEDTEST
DESCRIPTOR.message_types_by_name['TestResult'] = _TESTRESULT
DESCRIPTOR.message_types_by_name['TestFailure'] = _TESTFAILURE
DESCRIPTOR.message_types_by_name['ResizeTerm'] = _RESIZETERM
DESCRIPTOR.message_types_by_name['SaneTerm'] = _SANETERM
DESCRIPTOR.message_types_by_name['LintResults'] = _LINTRESULTS
DESCRIPTOR.message_types_by_name['LintResult'] = _LINTRESULT
DESCRIPTOR.message_types_by_name['OK'] = _OK
DESCRIPTOR.message_types_by_name['Move'] = _MOVE
DESCRIPTOR.message_types_by_name['Files'] = _FILES
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['Clear'] = _CLEAR
DESCRIPTOR.message_types_by_name['Toast'] = _TOAST
DESCRIPTOR.message_types_by_name['RunMain'] = _RUNMAIN
DESCRIPTOR.message_types_by_name['OpenChannel'] = _OPENCHANNEL
DESCRIPTOR.message_types_by_name['OpenChannelRes'] = _OPENCHANNELRES
DESCRIPTOR.message_types_by_name['CloseChannel'] = _CLOSECHANNEL
DESCRIPTOR.message_types_by_name['CloseChannelRes'] = _CLOSECHANNELRES
DESCRIPTOR.message_types_by_name['ContainerState'] = _CONTAINERSTATE
DESCRIPTOR.message_types_by_name['PortOpen'] = _PORTOPEN
DESCRIPTOR.message_types_by_name['OTFetchRequest'] = _OTFETCHREQUEST
DESCRIPTOR.message_types_by_name['OTFetchResponse'] = _OTFETCHRESPONSE
DESCRIPTOR.message_types_by_name['OTPacket'] = _OTPACKET
DESCRIPTOR.message_types_by_name['OTRuneTransformOp'] = _OTRUNETRANSFORMOP
DESCRIPTOR.message_types_by_name['OTStatus'] = _OTSTATUS
DESCRIPTOR.message_types_by_name['OTCursor'] = _OTCURSOR
DESCRIPTOR.message_types_by_name['ChatMessage'] = _CHATMESSAGE
DESCRIPTOR.message_types_by_name['ChatTyping'] = _CHATTYPING
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['Roster'] = _ROSTER
DESCRIPTOR.message_types_by_name['Exec'] = _EXEC
DESCRIPTOR.message_types_by_name['Package'] = _PACKAGE
DESCRIPTOR.message_types_by_name['PackageSearch'] = _PACKAGESEARCH
DESCRIPTOR.message_types_by_name['PackageSearchResp'] = _PACKAGESEARCHRESP
DESCRIPTOR.message_types_by_name['PackageInfo'] = _PACKAGEINFO
DESCRIPTOR.message_types_by_name['PackageInfoResp'] = _PACKAGEINFORESP
DESCRIPTOR.message_types_by_name['PackageAdd'] = _PACKAGEADD
DESCRIPTOR.message_types_by_name['PackageRemove'] = _PACKAGEREMOVE
DESCRIPTOR.message_types_by_name['PackageInstall'] = _PACKAGEINSTALL
DESCRIPTOR.message_types_by_name['PackageListSpecfile'] = _PACKAGELISTSPECFILE
DESCRIPTOR.message_types_by_name['PackageListSpecfileResp'] = _PACKAGELISTSPECFILERESP
DESCRIPTOR.message_types_by_name['PackageCacheSave'] = _PACKAGECACHESAVE
DESCRIPTOR.message_types_by_name['ChatScrollback'] = _CHATSCROLLBACK
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
DESCRIPTOR.enum_types_by_name['FileAuthMethod'] = _FILEAUTHMETHOD
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
  'DESCRIPTOR' : _COMMAND,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Command)
  })
_sym_db.RegisterMessage(Command)

Audio = _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {
  'DESCRIPTOR' : _AUDIO,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Audio)
  })
_sym_db.RegisterMessage(Audio)

ReadMeta = _reflection.GeneratedProtocolMessageType('ReadMeta', (_message.Message,), {
  'DESCRIPTOR' : _READMETA,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ReadMeta)
  })
_sym_db.RegisterMessage(ReadMeta)

WriteMeta = _reflection.GeneratedProtocolMessageType('WriteMeta', (_message.Message,), {
  'DESCRIPTOR' : _WRITEMETA,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.WriteMeta)
  })
_sym_db.RegisterMessage(WriteMeta)

AppendMeta = _reflection.GeneratedProtocolMessageType('AppendMeta', (_message.Message,), {
  'DESCRIPTOR' : _APPENDMETA,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.AppendMeta)
  })
_sym_db.RegisterMessage(AppendMeta)

BootStatus = _reflection.GeneratedProtocolMessageType('BootStatus', (_message.Message,), {
  'DESCRIPTOR' : _BOOTSTATUS,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.BootStatus)
  })
_sym_db.RegisterMessage(BootStatus)

Pid1Config = _reflection.GeneratedProtocolMessageType('Pid1Config', (_message.Message,), {
  'DESCRIPTOR' : _PID1CONFIG,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Pid1Config)
  })
_sym_db.RegisterMessage(Pid1Config)

FSLock = _reflection.GeneratedProtocolMessageType('FSLock', (_message.Message,), {
  'DESCRIPTOR' : _FSLOCK,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.FSLock)
  })
_sym_db.RegisterMessage(FSLock)

FSSnapshot = _reflection.GeneratedProtocolMessageType('FSSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _FSSNAPSHOT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.FSSnapshot)
  })
_sym_db.RegisterMessage(FSSnapshot)

SubscribeFile = _reflection.GeneratedProtocolMessageType('SubscribeFile', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEFILE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.SubscribeFile)
  })
_sym_db.RegisterMessage(SubscribeFile)

FileEvent = _reflection.GeneratedProtocolMessageType('FileEvent', (_message.Message,), {
  'DESCRIPTOR' : _FILEEVENT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.FileEvent)
  })
_sym_db.RegisterMessage(FileEvent)

Flush = _reflection.GeneratedProtocolMessageType('Flush', (_message.Message,), {
  'DESCRIPTOR' : _FLUSH,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Flush)
  })
_sym_db.RegisterMessage(Flush)

OTLinkFile = _reflection.GeneratedProtocolMessageType('OTLinkFile', (_message.Message,), {
  'DESCRIPTOR' : _OTLINKFILE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTLinkFile)
  })
_sym_db.RegisterMessage(OTLinkFile)

Auth = _reflection.GeneratedProtocolMessageType('Auth', (_message.Message,), {
  'DESCRIPTOR' : _AUTH,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Auth)
  })
_sym_db.RegisterMessage(Auth)

VCREntry = _reflection.GeneratedProtocolMessageType('VCREntry', (_message.Message,), {
  'DESCRIPTOR' : _VCRENTRY,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.VCREntry)
  })
_sym_db.RegisterMessage(VCREntry)

StartVCR = _reflection.GeneratedProtocolMessageType('StartVCR', (_message.Message,), {
  'DESCRIPTOR' : _STARTVCR,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.StartVCR)
  })
_sym_db.RegisterMessage(StartVCR)

ReadVCR = _reflection.GeneratedProtocolMessageType('ReadVCR', (_message.Message,), {
  'DESCRIPTOR' : _READVCR,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ReadVCR)
  })
_sym_db.RegisterMessage(ReadVCR)

VCRLog = _reflection.GeneratedProtocolMessageType('VCRLog', (_message.Message,), {
  'DESCRIPTOR' : _VCRLOG,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.VCRLog)
  })
_sym_db.RegisterMessage(VCRLog)

ExecInfo = _reflection.GeneratedProtocolMessageType('ExecInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXECINFO,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ExecInfo)
  })
_sym_db.RegisterMessage(ExecInfo)

Debug = _reflection.GeneratedProtocolMessageType('Debug', (_message.Message,), {
  'DESCRIPTOR' : _DEBUG,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Debug)
  })
_sym_db.RegisterMessage(Debug)

FileAuthReq = _reflection.GeneratedProtocolMessageType('FileAuthReq', (_message.Message,), {
  'DESCRIPTOR' : _FILEAUTHREQ,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.FileAuthReq)
  })
_sym_db.RegisterMessage(FileAuthReq)

MultiFileAuthRes = _reflection.GeneratedProtocolMessageType('MultiFileAuthRes', (_message.Message,), {
  'DESCRIPTOR' : _MULTIFILEAUTHRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.MultiFileAuthRes)
  })
_sym_db.RegisterMessage(MultiFileAuthRes)

FileAuthRes = _reflection.GeneratedProtocolMessageType('FileAuthRes', (_message.Message,), {
  'DESCRIPTOR' : _FILEAUTHRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.FileAuthRes)
  })
_sym_db.RegisterMessage(FileAuthRes)

ListObjects = _reflection.GeneratedProtocolMessageType('ListObjects', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTS,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ListObjects)
  })
_sym_db.RegisterMessage(ListObjects)

ListObjectsResp = _reflection.GeneratedProtocolMessageType('ListObjectsResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSRESP,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ListObjectsResp)
  })
_sym_db.RegisterMessage(ListObjectsResp)

Disconnect = _reflection.GeneratedProtocolMessageType('Disconnect', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Disconnect)
  })
_sym_db.RegisterMessage(Disconnect)

Send = _reflection.GeneratedProtocolMessageType('Send', (_message.Message,), {
  'DESCRIPTOR' : _SEND,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Send)
  })
_sym_db.RegisterMessage(Send)

Recv = _reflection.GeneratedProtocolMessageType('Recv', (_message.Message,), {
  'DESCRIPTOR' : _RECV,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Recv)
  })
_sym_db.RegisterMessage(Recv)

Connect = _reflection.GeneratedProtocolMessageType('Connect', (_message.Message,), {
  'DESCRIPTOR' : _CONNECT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Connect)
  })
_sym_db.RegisterMessage(Connect)

Hint = _reflection.GeneratedProtocolMessageType('Hint', (_message.Message,), {
  'DESCRIPTOR' : _HINT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Hint)
  })
_sym_db.RegisterMessage(Hint)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Ping)
  })
_sym_db.RegisterMessage(Ping)

Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), {
  'DESCRIPTOR' : _PONG,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Pong)
  })
_sym_db.RegisterMessage(Pong)

Hello = _reflection.GeneratedProtocolMessageType('Hello', (_message.Message,), {
  'DESCRIPTOR' : _HELLO,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Hello)
  })
_sym_db.RegisterMessage(Hello)

Goodbye = _reflection.GeneratedProtocolMessageType('Goodbye', (_message.Message,), {
  'DESCRIPTOR' : _GOODBYE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Goodbye)
  })
_sym_db.RegisterMessage(Goodbye)

CheckChanges = _reflection.GeneratedProtocolMessageType('CheckChanges', (_message.Message,), {
  'DESCRIPTOR' : _CHECKCHANGES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.CheckChanges)
  })
_sym_db.RegisterMessage(CheckChanges)

EnsurePackages = _reflection.GeneratedProtocolMessageType('EnsurePackages', (_message.Message,), {
  'DESCRIPTOR' : _ENSUREPACKAGES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.EnsurePackages)
  })
_sym_db.RegisterMessage(EnsurePackages)

Start = _reflection.GeneratedProtocolMessageType('Start', (_message.Message,), {
  'DESCRIPTOR' : _START,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Start)
  })
_sym_db.RegisterMessage(Start)

DebugStatus = _reflection.GeneratedProtocolMessageType('DebugStatus', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGSTATUS,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.DebugStatus)
  })
_sym_db.RegisterMessage(DebugStatus)

StackFrame = _reflection.GeneratedProtocolMessageType('StackFrame', (_message.Message,), {
  'DESCRIPTOR' : _STACKFRAME,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.StackFrame)
  })
_sym_db.RegisterMessage(StackFrame)

ContainedTest = _reflection.GeneratedProtocolMessageType('ContainedTest', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINEDTEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ContainedTest)
  })
_sym_db.RegisterMessage(ContainedTest)

TestResult = _reflection.GeneratedProtocolMessageType('TestResult', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESULT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.TestResult)
  })
_sym_db.RegisterMessage(TestResult)

TestFailure = _reflection.GeneratedProtocolMessageType('TestFailure', (_message.Message,), {
  'DESCRIPTOR' : _TESTFAILURE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.TestFailure)
  })
_sym_db.RegisterMessage(TestFailure)

ResizeTerm = _reflection.GeneratedProtocolMessageType('ResizeTerm', (_message.Message,), {
  'DESCRIPTOR' : _RESIZETERM,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ResizeTerm)
  })
_sym_db.RegisterMessage(ResizeTerm)

SaneTerm = _reflection.GeneratedProtocolMessageType('SaneTerm', (_message.Message,), {
  'DESCRIPTOR' : _SANETERM,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.SaneTerm)
  })
_sym_db.RegisterMessage(SaneTerm)

LintResults = _reflection.GeneratedProtocolMessageType('LintResults', (_message.Message,), {
  'DESCRIPTOR' : _LINTRESULTS,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.LintResults)
  })
_sym_db.RegisterMessage(LintResults)

LintResult = _reflection.GeneratedProtocolMessageType('LintResult', (_message.Message,), {
  'DESCRIPTOR' : _LINTRESULT,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.LintResult)
  })
_sym_db.RegisterMessage(LintResult)

OK = _reflection.GeneratedProtocolMessageType('OK', (_message.Message,), {
  'DESCRIPTOR' : _OK,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OK)
  })
_sym_db.RegisterMessage(OK)

Move = _reflection.GeneratedProtocolMessageType('Move', (_message.Message,), {
  'DESCRIPTOR' : _MOVE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Move)
  })
_sym_db.RegisterMessage(Move)

Files = _reflection.GeneratedProtocolMessageType('Files', (_message.Message,), {
  'DESCRIPTOR' : _FILES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Files)
  })
_sym_db.RegisterMessage(Files)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.File)
  })
_sym_db.RegisterMessage(File)

Clear = _reflection.GeneratedProtocolMessageType('Clear', (_message.Message,), {
  'DESCRIPTOR' : _CLEAR,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Clear)
  })
_sym_db.RegisterMessage(Clear)

Toast = _reflection.GeneratedProtocolMessageType('Toast', (_message.Message,), {
  'DESCRIPTOR' : _TOAST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Toast)
  })
_sym_db.RegisterMessage(Toast)

RunMain = _reflection.GeneratedProtocolMessageType('RunMain', (_message.Message,), {
  'DESCRIPTOR' : _RUNMAIN,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.RunMain)
  })
_sym_db.RegisterMessage(RunMain)

OpenChannel = _reflection.GeneratedProtocolMessageType('OpenChannel', (_message.Message,), {
  'DESCRIPTOR' : _OPENCHANNEL,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OpenChannel)
  })
_sym_db.RegisterMessage(OpenChannel)

OpenChannelRes = _reflection.GeneratedProtocolMessageType('OpenChannelRes', (_message.Message,), {
  'DESCRIPTOR' : _OPENCHANNELRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OpenChannelRes)
  })
_sym_db.RegisterMessage(OpenChannelRes)

CloseChannel = _reflection.GeneratedProtocolMessageType('CloseChannel', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECHANNEL,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.CloseChannel)
  })
_sym_db.RegisterMessage(CloseChannel)

CloseChannelRes = _reflection.GeneratedProtocolMessageType('CloseChannelRes', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECHANNELRES,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.CloseChannelRes)
  })
_sym_db.RegisterMessage(CloseChannelRes)

ContainerState = _reflection.GeneratedProtocolMessageType('ContainerState', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ContainerState)
  })
_sym_db.RegisterMessage(ContainerState)

PortOpen = _reflection.GeneratedProtocolMessageType('PortOpen', (_message.Message,), {
  'DESCRIPTOR' : _PORTOPEN,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PortOpen)
  })
_sym_db.RegisterMessage(PortOpen)

OTFetchRequest = _reflection.GeneratedProtocolMessageType('OTFetchRequest', (_message.Message,), {
  'DESCRIPTOR' : _OTFETCHREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTFetchRequest)
  })
_sym_db.RegisterMessage(OTFetchRequest)

OTFetchResponse = _reflection.GeneratedProtocolMessageType('OTFetchResponse', (_message.Message,), {
  'DESCRIPTOR' : _OTFETCHRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTFetchResponse)
  })
_sym_db.RegisterMessage(OTFetchResponse)

OTPacket = _reflection.GeneratedProtocolMessageType('OTPacket', (_message.Message,), {
  'DESCRIPTOR' : _OTPACKET,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTPacket)
  })
_sym_db.RegisterMessage(OTPacket)

OTRuneTransformOp = _reflection.GeneratedProtocolMessageType('OTRuneTransformOp', (_message.Message,), {
  'DESCRIPTOR' : _OTRUNETRANSFORMOP,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTRuneTransformOp)
  })
_sym_db.RegisterMessage(OTRuneTransformOp)

OTStatus = _reflection.GeneratedProtocolMessageType('OTStatus', (_message.Message,), {
  'DESCRIPTOR' : _OTSTATUS,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTStatus)
  })
_sym_db.RegisterMessage(OTStatus)

OTCursor = _reflection.GeneratedProtocolMessageType('OTCursor', (_message.Message,), {
  'DESCRIPTOR' : _OTCURSOR,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.OTCursor)
  })
_sym_db.RegisterMessage(OTCursor)

ChatMessage = _reflection.GeneratedProtocolMessageType('ChatMessage', (_message.Message,), {
  'DESCRIPTOR' : _CHATMESSAGE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ChatMessage)
  })
_sym_db.RegisterMessage(ChatMessage)

ChatTyping = _reflection.GeneratedProtocolMessageType('ChatTyping', (_message.Message,), {
  'DESCRIPTOR' : _CHATTYPING,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ChatTyping)
  })
_sym_db.RegisterMessage(ChatTyping)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.User)
  })
_sym_db.RegisterMessage(User)

Roster = _reflection.GeneratedProtocolMessageType('Roster', (_message.Message,), {
  'DESCRIPTOR' : _ROSTER,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Roster)
  })
_sym_db.RegisterMessage(Roster)

Exec = _reflection.GeneratedProtocolMessageType('Exec', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXEC_ENVENTRY,
    '__module__' : 'api_pb2'
    # @@protoc_insertion_point(class_scope:api.Exec.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _EXEC,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Exec)
  })
_sym_db.RegisterMessage(Exec)
_sym_db.RegisterMessage(Exec.EnvEntry)

Package = _reflection.GeneratedProtocolMessageType('Package', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Package)
  })
_sym_db.RegisterMessage(Package)

PackageSearch = _reflection.GeneratedProtocolMessageType('PackageSearch', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGESEARCH,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageSearch)
  })
_sym_db.RegisterMessage(PackageSearch)

PackageSearchResp = _reflection.GeneratedProtocolMessageType('PackageSearchResp', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGESEARCHRESP,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageSearchResp)
  })
_sym_db.RegisterMessage(PackageSearchResp)

PackageInfo = _reflection.GeneratedProtocolMessageType('PackageInfo', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEINFO,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageInfo)
  })
_sym_db.RegisterMessage(PackageInfo)

PackageInfoResp = _reflection.GeneratedProtocolMessageType('PackageInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEINFORESP,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageInfoResp)
  })
_sym_db.RegisterMessage(PackageInfoResp)

PackageAdd = _reflection.GeneratedProtocolMessageType('PackageAdd', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEADD,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageAdd)
  })
_sym_db.RegisterMessage(PackageAdd)

PackageRemove = _reflection.GeneratedProtocolMessageType('PackageRemove', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEREMOVE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageRemove)
  })
_sym_db.RegisterMessage(PackageRemove)

PackageInstall = _reflection.GeneratedProtocolMessageType('PackageInstall', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEINSTALL,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageInstall)
  })
_sym_db.RegisterMessage(PackageInstall)

PackageListSpecfile = _reflection.GeneratedProtocolMessageType('PackageListSpecfile', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGELISTSPECFILE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageListSpecfile)
  })
_sym_db.RegisterMessage(PackageListSpecfile)

PackageListSpecfileResp = _reflection.GeneratedProtocolMessageType('PackageListSpecfileResp', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGELISTSPECFILERESP,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageListSpecfileResp)
  })
_sym_db.RegisterMessage(PackageListSpecfileResp)

PackageCacheSave = _reflection.GeneratedProtocolMessageType('PackageCacheSave', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGECACHESAVE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.PackageCacheSave)
  })
_sym_db.RegisterMessage(PackageCacheSave)

ChatScrollback = _reflection.GeneratedProtocolMessageType('ChatScrollback', (_message.Message,), {
  'DESCRIPTOR' : _CHATSCROLLBACK,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.ChatScrollback)
  })
_sym_db.RegisterMessage(ChatScrollback)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {
  'DESCRIPTOR' : _METRICS,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:api.Metrics)
  })
_sym_db.RegisterMessage(Metrics)


_EXEC_ENVENTRY._options = None
# @@protoc_insertion_point(module_scope)
